Compiles the zone de sante masques
compile_masques_national.RdCompared to the original version of the function, this masque uses the IMPORTRANGE() function in Google Sheets to copy over the information. Rather than having multiple imports and exports.